<?php

/**
 * @file
 * Theme functions used for normal file output.
 */

/**
 * Implements template_preprocess_hook() for dbtables_views.
 *
 * @param array $vars
 *   All the variables available for the theme.
 */
function template_preprocess_dbtables_view(&$vars) {
  $vars['dbtable_tabs'] = theme('dbtables_tabs', 1);
  $vars['table'] = '';
  $vars['pager'] = '';

  if (isset($vars['dbtable'])) {
    if (trim($vars['dbtable']['name']) != '') {
      drupal_set_title(t('Table') . ': ' . $vars['dbtable']['name']);
    }

    $query = "SELECT * FROM " . $vars['dbtable']['name'];
    $limit1 = " LIMIT 0, 1";
    $q = db_query($query . $limit1);
    $r = db_fetch_array($q);
    if (!empty($r)) {
      $header = array();
      $i = 0;
      foreach ($r as $key => $value) {
        if ($i == 0) {
          $header[$i]['sort'] = 'desc';
        }
        $header[$i]['data'] = $key;
        $header[$i]['field'] = $key;
        $i++;
      }

      $element = 0;
      $limit = 20;
      $count_query = "SELECT COUNT(*) FROM (" . $query . ") AS count_query";
      $q = pager_query($query . tablesort_sql($header), $limit, $element, $count_query);
      $rows = array();
      while ($r = db_fetch_array($q)) {
        $rows[]['data'] = $r;
      }

      $vars['table'] = theme('table', $header, $rows);
      $vars['pager'] = theme('pager', NULL, $limit, $element);
    }
    else {
      $vars['table'] = t('Empty table.');
    }
  }
}

/**
 * Implements template_preprocess_hook() for dbtables_info.
 *
 * @param array $vars
 *   All the variables available for the theme.
 */
function template_preprocess_dbtables_info(&$vars) {
  $vars['dbtable_tabs'] = theme('dbtables_tabs', 0);
  $vars['dbtable_desc'] = '';
  $vars['dbtable_info'] = '';

  if (isset($vars['dbtable'])) {
    if (trim($vars['dbtable']['name']) != '') {
      drupal_set_title(t('Table') . ': ' . $vars['dbtable']['name']);
    }

    if (trim($vars['dbtable']['description']) != '') {
      $vars['dbtable_desc'] = '<p><b>' . t('Description') . '</b>: ' . $vars['dbtable']['description'] . '</p>';
    }

    $header = array(
      0 => t('Name'),
      1 => t('Datatype'),
      2 => t('Length/Set'),
      3 => t('Unsigned'),
      4 => t('Not Null'),
      5 => t('Default'),
      6 => t('Comment'),
    );

    $rows = array();
    $i = 0;
    foreach ($vars['dbtable']['fields'] as $key => $field) {
      $rows[$i]['data'][0] = $key;
      $rows[$i]['data'][1] = (isset($field['type'])) ? $field['type'] : '';
      $rows[$i]['data'][2] = (isset($field['length'])) ? $field['length'] : '';
      $rows[$i]['data'][3] = (isset($field['unsigned'])) ? $field['unsigned'] : '';
      $rows[$i]['data'][4] = (isset($field['not null'])) ? $field['not null'] : '';
      $rows[$i]['data'][5] = (isset($field['default'])) ? $field['default'] : '';
      $rows[$i]['data'][6] = (isset($field['description'])) ? $field['description'] : '';
      $i++;
    }
    $vars['dbtable_info'] = theme('table', $header, $rows);
  }
}

/**
 * Implements template_preprocess_hook() for dbtables_tabs.
 *
 * @param array $vars
 *   All the variables available for the theme.
 */
function template_preprocess_dbtables_tabs(&$vars) {
  drupal_add_css(drupal_get_path('module', 'dbtables') . '/css/dbtables.css');
  $text0 = t('Info Table');
  $path0 = 'admin/content/dbtables/' . arg(3) . '/info';
  $text1 = t('View Table');
  $path1 = 'admin/content/dbtables/' . arg(3) . '/view';
  switch ($vars['tab']) {
    case '0':
      $vars['menu'][0] = '<li class="active">' . l($text0, $path0) . '</li>';
      $vars['menu'][1] = '<li>' . l($text1, $path1) . '</li>';
      break;

    case '1':
      $vars['menu'][0] = '<li>' . l($text0, $path0) . '</li>';
      $vars['menu'][1] = '<li class="active">' . l($text1, $path1) . '</li>';
      break;
  }
  $text2 = t('Change Table');
  $path2 = 'admin/content/dbtables';
  $vars['menu'][2] = '<li>' . l($text2, $path2) . '</li>';
}
